/**
 * Service
 * @class ApPreferenceService
 * @param {Object} store - Redux store
 * @param {Object} options - Optional settings
 */
'use strict'

const { ApService } = require('apeman-service-base')
const abind = require('abind')
const co = require('co')

/** @lends ApPreferenceService */
class ApPreferenceService extends ApService {
  constructor (store, options = {}) {
    super(store)
    const s = this
    abind(s, { proto: ApPreferenceService.prototype })
    abind(s)
  }

  // ---------------
  // Getter Methods
  // ---------------

  /**
   * Get preference value
   * @param fieldName
   * @returns {*}
   */
  getPreference (fieldName) {
    const s = this
    return s.store.get(fieldName)
  }

  // ---------------
  // Action Methods
  // ---------------

  /**
   * Set preference
   * @param {string} fieldName - Name of preference field
   * @param {*} value - Value to set
   * @returns {Promise}
   */
  setPreference (fieldName, value) {
    const s = this
    return co(function * () {
      s.store.set(fieldName, value)
    })
  }

  /**
   * Delete preference
   * @param {string} fieldName - Name of preference field
   * @returns {Promise}
   */
  deletePreference (fieldName) {
    const s = this
    return co(function * () {
      s.store.del(fieldName)
    })
  }
}

module.exports = ApPreferenceService
